@@ -54,6 +54,7 @@
 use crate::{identifier, length, Buffer, Der, DerRef, Error, IdRef, Length};
 use core::convert::TryFrom;
 use core::ops::Deref;
+use num::PrimInt;
 use std::borrow::Borrow;
 
 /// `BerRef` is a wrapper of `[u8]` and represents a BER.
@@ -180,7 +181,7 @@ impl BerRef {
         let id = identifier::shrink_to_fit_unchecked(bytes);
         let parsing = &bytes[id.len()..];
 
-        let total_len = match length::try_from(parsing).unwrap() {
+        let total_len = match length::from_bytes_starts_with_unchecked(parsing) {
             (Length::Definite(len), parsing) => bytes.len() - parsing.len() + len,
             (Length::Indefinite, parsing) => {
                 let mut total_len = bytes.len() - parsing.len();
@@ -270,7 +271,7 @@ impl BerRef {
     pub fn length(&self) -> Length {
         let id_len = self.id().as_ref().len();
         let bytes = &self.bytes[id_len..];
-        length::try_from(bytes).unwrap().0
+        unsafe { length::from_bytes_starts_with_unchecked(bytes).0 }
     }
 
     /// Provides a reference to the 'contents' octets of `self` .
@@ -291,7 +292,7 @@ impl BerRef {
     pub fn contents(&self) -> &[u8] {
         let id_len = self.id().as_ref().len();
         let bytes = &self.bytes[id_len..];
-        length::try_from(bytes).unwrap().1
+        unsafe { length::from_bytes_starts_with_unchecked(bytes).1 }
     }
 }
 
@@ -406,7 +407,9 @@ impl Ber {
         Self::from(Der::boolean(val))
     }
 
-    /// Returns a new instance representing ingeger.
+    /// Returns a new instance representing integer.
+    ///
+    /// Type `T` should be the builtin primitive integer types (e.g., u8, u32, isize, i128, ...)
     ///
     /// # Examples
     ///
@@ -419,7 +422,10 @@ impl Ber {
     /// assert_eq!(IdRef::integer(), ber.id());
     /// assert_eq!(val, contents::to_integer(ber.contents()).unwrap());
     /// ```
-    pub fn integer(val: i128) -> Self {
+    pub fn integer<T>(val: T) -> Self
+    where
+        T: PrimInt,
+    {
         Self::from(Der::integer(val))
     }
 
