@@ -54,6 +54,7 @@
 use crate::{contents, identifier, length, Buffer, Error, IdRef, Length};
 use core::convert::TryFrom;
 use core::ops::Deref;
+use num::PrimInt;
 use std::borrow::Borrow;
 
 /// `DerRef` is a wrapper of `[u8]` and represents DER.
@@ -160,7 +161,7 @@ impl DerRef {
         let id = identifier::shrink_to_fit_unchecked(bytes);
         let parsing = &bytes[id.len()..];
 
-        let (len, parsing) = match length::try_from(parsing).unwrap() {
+        let (len, parsing) = match length::from_bytes_starts_with_unchecked(parsing) {
             (Length::Definite(len), parsing) => (len, parsing),
             _ => panic!("{}", Error::IndefiniteLength),
         };
@@ -243,7 +244,7 @@ impl DerRef {
     pub fn length(&self) -> Length {
         let id_len = self.id().as_ref().len();
         let bytes = &self.bytes[id_len..];
-        length::try_from(bytes).unwrap().0
+        unsafe { length::from_bytes_starts_with_unchecked(bytes).0 }
     }
 
     /// Returns a reference to the contents octets of `self` .
@@ -264,7 +265,7 @@ impl DerRef {
     pub fn contents(&self) -> &[u8] {
         let id_len = self.id().as_ref().len();
         let bytes = &self.bytes[id_len..];
-        length::try_from(bytes).unwrap().1
+        unsafe { length::from_bytes_starts_with_unchecked(bytes).1 }
     }
 }
 
@@ -413,7 +414,9 @@ impl Der {
         Self::new(IdRef::boolean(), contents::from_bool(val).as_ref())
     }
 
-    /// Returns a new instance representing ingeger.
+    /// Returns a new instance representing integer.
+    ///
+    /// Type `T` should be the builtin primitive integer types (e.g., u8, u32, isize, i128, ...)
     ///
     /// # Examples
     ///
@@ -426,7 +429,10 @@ impl Der {
     /// assert_eq!(IdRef::integer(), der.id());
     /// assert_eq!(val, contents::to_integer(der.contents()).unwrap());
     /// ```
-    pub fn integer(val: i128) -> Self {
+    pub fn integer<T>(val: T) -> Self
+    where
+        T: PrimInt,
+    {
         Self::new(IdRef::integer(), contents::from_integer(val).as_ref())
     }
 
