@@ -70,7 +70,7 @@ pub enum ClassTag {
     Private = 0xc0,
 }
 
-/// `PCTag` represents Private/Constructed flag of identifier.
+/// `PCTag` represents Primitive/Constructed flag of identifier.
 #[repr(u8)]
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub enum PCTag {
@@ -1293,8 +1293,6 @@ impl TryFrom<&[u8]> for Id {
     ///
     /// # Warnings
     ///
-    /// # Warnings
-    ///
     /// ASN.1 reserves some universal identifier numbers and they should not be used, however,
     /// this function ignores that. For example, number 15 (0x0f) is reserved for now, but this
     /// functions returns `Ok` .
@@ -1597,7 +1595,7 @@ mod tests {
                     bytes[1] = 0x83;
                     bytes[19] = 0x7f;
                     let id = <&IdRef>::try_from(&bytes as &[u8]).unwrap();
-                    assert_eq!(u128::MAX, id.number().unwrap());
+                    assert_eq!(std::u128::MAX, id.number().unwrap());
 
                     let mut bytes: [u8; 20] = [0x80; 20];
                     bytes[0] = first;
@@ -1614,7 +1612,17 @@ mod tests {
     fn new() {
         for &cl in CLASSES {
             for &pc in PCS {
-                for &num in &[0, 30, 31, 0x7f, 0x80, 0x3fff, 0x8000, 0x1fffff, u128::MAX] {
+                for &num in &[
+                    0,
+                    30,
+                    31,
+                    0x7f,
+                    0x80,
+                    0x3fff,
+                    0x8000,
+                    0x1fffff,
+                    std::u128::MAX,
+                ] {
                     let id = Id::new(cl, pc, num);
                     let idref = <&IdRef>::try_from(id.as_ref() as &[u8]).unwrap();
                     assert_eq!(idref.as_ref(), id.as_ref() as &[u8]);
